{% extends base %}

{% block title %}Visualize Accelerometry signals{% endblock %}

{% block preamble %}
<link rel="icon" type="image/x-icon" href="visualize_accelerometry/static/favicon.ico">
<style>
  @import url(https://fonts.googleapis.com/css?family=Noto+Sans);
  body {
    font-family: 'Noto Sans', sans-serif;
    -webkit-font-smoothing: antialiased;
    text-rendering: optimizeLegibility;
    color: #000000;
    background: none;
  }
  .bk.forward_btn {
  border-color: transparent !important;
  background-color: transparent !important;
  font-size: xx-large !important;
}
</style>
{% endblock %}
<body>
{{ plot_div }}
{{ plot_script }}
</body>